Installation — cliff 0.5.1 documentation

### Navigation

- index
- next |
- previous |
- cliff 0.5.1 documentation »

# Installation

## Python Versions

cliff is being developed under Python 2.7 and tested with Python 3.2.

## Basic Installation

cliff should be installed into the same site-packages area where the application and extensions are installed (either a virtualenv or the global site-packages). You may need administrative privileges to do that. The easiest way to install it is using pip:

    $ pip install cliff

or:

    $ sudo pip install cliff

## Source Code

The source is hosted on github: https://github.com/dreamhost/cliff

## Reporting Bugs

Please report bugs through the github project: https://github.com/dreamhost/cliff/issues

### Navigation

- index
- next |
- previous |
- cliff 0.5.1 documentation »